@@ -13,10 +13,7 @@ import jaraco.path
 from distutils.dist import Distribution, fix_help_options
 from distutils.cmd import Command
 
-from test.support import captured_stdout, captured_stderr
-from .py38compat import TESTFN
 from distutils.tests import support
-from distutils import log
 
 
 pydistutils_cfg = '.' * (os.name == 'posix') + 'pydistutils.cfg'
@@ -53,10 +50,7 @@ def clear_argv():
 @support.combine_markers
 @pytest.mark.usefixtures('save_env')
 @pytest.mark.usefixtures('save_argv')
-class TestDistributionBehavior(
-    support.LoggingSilencer,
-    support.TempdirManager,
-):
+class TestDistributionBehavior(support.TempdirManager):
     def create_distribution(self, configfiles=()):
         d = TestDistribution()
         d._config_files = configfiles
@@ -95,15 +89,15 @@ class TestDistributionBehavior(
         'distutils' not in Distribution.parse_config_files.__module__,
         reason='Cannot test when virtualenv has monkey-patched Distribution',
     )
-    def test_venv_install_options(self, request):
+    def test_venv_install_options(self, tmp_path):
         sys.argv.append("install")
-        request.addfinalizer(functools.partial(os.unlink, TESTFN))
+        file = str(tmp_path / 'file')
 
         fakepath = '/somedir'
 
         jaraco.path.build(
             {
-                TESTFN: f"""
+                file: f"""
                     [install]
                     install-base = {fakepath}
                     install-platbase = {fakepath}
@@ -124,9 +118,9 @@ class TestDistributionBehavior(
 
         # Base case: Not in a Virtual Environment
         with mock.patch.multiple(sys, prefix='/a', base_prefix='/a'):
-            d = self.create_distribution([TESTFN])
+            d = self.create_distribution([file])
 
-        option_tuple = (TESTFN, fakepath)
+        option_tuple = (file, fakepath)
 
         result_dict = {
             'install_base': option_tuple,
@@ -153,35 +147,35 @@ class TestDistributionBehavior(
 
         # Test case: In a Virtual Environment
         with mock.patch.multiple(sys, prefix='/a', base_prefix='/b'):
-            d = self.create_distribution([TESTFN])
+            d = self.create_distribution([file])
 
         for key in result_dict.keys():
             assert key not in d.command_options.get('install', {})
 
-    def test_command_packages_configfile(self, request, clear_argv):
+    def test_command_packages_configfile(self, tmp_path, clear_argv):
         sys.argv.append("build")
-        request.addfinalizer(functools.partial(os.unlink, TESTFN))
+        file = str(tmp_path / "file")
         jaraco.path.build(
             {
-                TESTFN: """
+                file: """
                     [global]
                     command_packages = foo.bar, splat
                     """,
             }
         )
 
-        d = self.create_distribution([TESTFN])
+        d = self.create_distribution([file])
         assert d.get_command_packages() == ["distutils.command", "foo.bar", "splat"]
 
         # ensure command line overrides config:
         sys.argv[1:] = ["--command-packages", "spork", "build"]
-        d = self.create_distribution([TESTFN])
+        d = self.create_distribution([file])
         assert d.get_command_packages() == ["distutils.command", "spork"]
 
         # Setting --command-packages to '' should cause the default to
         # be used even if a config file specified something else:
         sys.argv[1:] = ["--command-packages", "", "build"]
-        d = self.create_distribution([TESTFN])
+        d = self.create_distribution([file])
         assert d.get_command_packages() == ["distutils.command"]
 
     def test_empty_options(self, request):
@@ -241,10 +235,8 @@ class TestDistributionBehavior(
     def test_announce(self):
         # make sure the level is known
         dist = Distribution()
-        args = ('ok',)
-        kwargs = {'level': 'ok2'}
-        with pytest.raises(ValueError):
-            dist.announce(args, kwargs)
+        with pytest.raises(TypeError):
+            dist.announce('ok', level='ok2')
 
     def test_find_config_files_disable(self, temp_home):
         # Ticket #1180: Allow user to disable their home config file.
@@ -259,6 +251,18 @@ class TestDistributionBehavior(
         # make sure --no-user-cfg disables the user cfg file
         assert len(all_files) - 1 == len(files)
 
+    @pytest.mark.skipif(
+        'platform.system() == "Windows"',
+        reason='Windows does not honor chmod 000',
+    )
+    def test_find_config_files_permission_error(self, fake_home):
+        """
+        Finding config files should not fail when directory is inaccessible.
+        """
+        fake_home.joinpath(pydistutils_cfg).write_text('')
+        fake_home.chmod(0o000)
+        Distribution().find_config_files()
+
 
 @pytest.mark.usefixtures('save_env')
 @pytest.mark.usefixtures('save_argv')
@@ -362,16 +366,15 @@ class TestMetadata(support.TempdirManager):
         meta = self.format_metadata(dist)
         assert 'Metadata-Version: 1.1' in meta
 
-    def test_classifier_invalid_type(self):
+    def test_classifier_invalid_type(self, caplog):
         attrs = {
             'name': 'Boa',
             'version': '3.0',
             'classifiers': ('Programming Language :: Python :: 3',),
         }
-        with captured_stderr() as error:
-            d = Distribution(attrs)
+        d = Distribution(attrs)
         # should have warning about passing a non-list
-        assert 'should be a list' in error.getvalue()
+        assert 'should be a list' in caplog.messages[0]
         # should be converted to a list
         assert isinstance(d.metadata.classifiers, list)
         assert d.metadata.classifiers == list(attrs['classifiers'])
@@ -385,16 +388,15 @@ class TestMetadata(support.TempdirManager):
         dist = Distribution(attrs)
         assert dist.get_keywords() == ['spam', 'eggs', 'life of brian']
 
-    def test_keywords_invalid_type(self):
+    def test_keywords_invalid_type(self, caplog):
         attrs = {
             'name': 'Monty',
             'version': '1.0',
             'keywords': ('spam', 'eggs', 'life of brian'),
         }
-        with captured_stderr() as error:
-            d = Distribution(attrs)
+        d = Distribution(attrs)
         # should have warning about passing a non-list
-        assert 'should be a list' in error.getvalue()
+        assert 'should be a list' in caplog.messages[0]
         # should be converted to a list
         assert isinstance(d.metadata.keywords, list)
         assert d.metadata.keywords == list(attrs['keywords'])
@@ -408,16 +410,15 @@ class TestMetadata(support.TempdirManager):
         dist = Distribution(attrs)
         assert dist.get_platforms() == ['GNU/Linux', 'Some Evil Platform']
 
-    def test_platforms_invalid_types(self):
+    def test_platforms_invalid_types(self, caplog):
         attrs = {
             'name': 'Monty',
             'version': '1.0',
             'platforms': ('GNU/Linux', 'Some Evil Platform'),
         }
-        with captured_stderr() as error:
-            d = Distribution(attrs)
+        d = Distribution(attrs)
         # should have warning about passing a non-list
-        assert 'should be a list' in error.getvalue()
+        assert 'should be a list' in caplog.messages[0]
         # should be converted to a list
         assert isinstance(d.metadata.platforms, list)
         assert d.metadata.platforms == list(attrs['platforms'])
@@ -468,18 +469,17 @@ class TestMetadata(support.TempdirManager):
         assert fancy_options[0] == ('a', 'b', 'c')
         assert fancy_options[1] == (1, 2, 3)
 
-    def test_show_help(self, request):
+    def test_show_help(self, request, capsys):
         # smoke test, just makes sure some help is displayed
-        reset_log = functools.partial(log.set_threshold, log._global_log.threshold)
-        request.addfinalizer(reset_log)
         dist = Distribution()
         sys.argv = []
         dist.help = 1
         dist.script_name = 'setup.py'
-        with captured_stdout() as s:
-            dist.parse_command_line()
+        dist.parse_command_line()
 
-        output = [line for line in s.getvalue().split('\n') if line.strip() != '']
+        output = [
+            line for line in capsys.readouterr().out.split('\n') if line.strip() != ''
+        ]
         assert output
 
     def test_read_metadata(self):
